@@ -2,10 +2,40 @@ from enum import Enum, EnumMeta
 
 import numpy as np
 from PIL import Image
+import os
 
+import exifread
+
+
+def get_exif_orientation(image_path):
+    with open(image_path, 'rb') as f:
+        tags = exifread.process_file(f)
+    # Exifread uses 'Image Orientation' to store the orientation data
+    orientation_tag = 'Image Orientation'
+    if orientation_tag in tags:
+        # Convert the value to an integer
+        orientation_value = tags[orientation_tag].values[0]
+        # Return the orientation value
+        return orientation_value
+    else:
+        # No orientation tag found, return a default value
+        return 1
+def apply_rotation(image, orientation):
+    """
+    Applies rotation to the image based on the EXIF orientation.
+    """
+    if orientation == 3:
+        image = image.rotate(180, expand=True)
+    elif orientation == 6:
+        image = image.rotate(270, expand=True)
+    elif orientation == 8:
+        image = image.rotate(90, expand=True)
+
+    return image
 
 def image_path_to_array(image_path: str, input_format: str) -> np.ndarray:
     image = Image.open(image_path).convert(input_format.upper())
+    image=apply_rotation(image,get_exif_orientation(image_path))
     return np.array(image)
 
 
@@ -103,12 +133,9 @@ class FaceValidationCode(Enum, metaclass=FaceValidationCodeMeta):
     InvalidImage = -100  # Err = -100
     NoFace = -1  # faceNotDetected = -1
     ValidBiometric = 0  # Ok = 0
-    ImageSpoof = (
-        1  # TODO Check  deprecated or new code? this does not exist in cpp core
-    )
-    VideoSpoof = (
-        2  # TODO Check  deprecated or new code? this does not exist in cpp core
-    )
+    ImageSpoof =  1
+
+    VideoSpoof = 2 
     TooClose = 3  # faceTooClose = 3
     TooFaraway = 4  # faceTooFar = 4
     TooFarToRight = 5  # faceRight = 5
@@ -129,4 +156,6 @@ class FaceValidationCode(Enum, metaclass=FaceValidationCodeMeta):
     EyeBlink = 20  # EyeBlink = 20
     МouthOpened = 21  # МouthOpened = 21
     faceRotatedRight = 22
-    faceRotatedLeft = 23
\ No newline at end of file
+    faceRotatedLeft = 23
+
+    
\ No newline at end of file
